@@ -1,6 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Metareports;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Reports::Web::Controller::Tapper::Metareports::VERSION = '5.0.4';
+$Tapper::Reports::Web::Controller::Tapper::Metareports::VERSION = '5.0.5';
 # ABSTRACT: Tapper - Catalyst Controller Metareports
 
 use strict;
@@ -8,7 +8,6 @@ use warnings;
 use parent 'Tapper::Reports::Web::Controller::Base';
 
 use Try::Tiny;
-use Tapper::Benchmark;
 use List::MoreUtils qw( any );
 
 use 5.010;
@@ -120,7 +119,7 @@ sub detail : Local {
 
         # check for template parameter
         my %h_restriction_values;
-        for my $or_chart_line ( $or_c->stash->{chart}->chart_lines ) {
+        for my $or_chart_line ( $or_c->stash->{chart} ? $or_c->stash->{chart}->chart_lines : () ) {
             for my $or_restriction ( $or_chart_line->chart_line_restrictions ) {
                 if ( $or_restriction->is_template_restriction ) {
                     my $s_restricted_value =
@@ -254,6 +253,7 @@ sub get_chart_points : Local {
 
     # update tiny url counter if exists
     my $or_tiny_url;
+    my $NOW = DateTime->now();
     if ( my $i_chart_tiny_url_id = $h_params{chart_tiny_url} ) {
         $or_tiny_url = $or_schema
             ->resultset('ChartTinyUrls')
@@ -267,19 +267,23 @@ sub get_chart_points : Local {
             })
             ->first()
         ;
+        if ($or_tiny_url) {
         $or_tiny_url->visit_count( $or_tiny_url->visit_count() + 1 );
-        $or_tiny_url->last_visited(\'NOW()');
+        $or_tiny_url->last_visited($NOW);
         $or_tiny_url->update();
+        $or_c->stash->{tiny_url_count} = $or_tiny_url->visit_count;
+        }
     }
 
     if ( my @a_chart_lines = $or_chart->chart_lines ) {
 
         require JSON::XS;
         require YAML::Syck;
-        require Tapper::Benchmark;
-        my $or_bench = Tapper::Benchmark
-            ->new({ dbh => $or_schema->storage->dbh, })
-        ;
+        require Tapper::Config;
+        require BenchmarkAnything::Storage::Frontend::Lib;
+
+        my $balib = BenchmarkAnything::Storage::Frontend::Lib->new
+          (cfgfile => Tapper::Config->subconfig->{_last_used_tapper_config_file});
 
         require DateTime;
         require DateTime::Format::Epoch;
@@ -344,11 +348,11 @@ sub get_chart_points : Local {
             for my $s_axis (qw/ x y /) {
                 for my $or_element ( sort { $a->chart_line_axis_element_number <=> $b->chart_line_axis_element_number } $or_chart_line->chart_axis_elements ) {
                     if ( $or_element->chart_line_axis eq $s_axis && $or_element->axis_column ) {
-                        push @{$hr_chart_search->{order_by}}, {
-                            column    => $or_element->axis_column->chart_line_axis_column,
-                            direction => 'DESC',
-                            numeric   => $h_axis_type{$s_axis} eq 'numeric',
-                        };
+                        push @{$hr_chart_search->{order_by}}, [
+                            $or_element->axis_column->chart_line_axis_column,
+                            'DESC',
+                            { numeric   => $h_axis_type{$s_axis} eq 'numeric' },
+                        ];
                     }
                 }
             }
@@ -370,11 +374,11 @@ sub get_chart_points : Local {
                         ->all
                     ;
                     if ( @a_bench_value_ids ) {
-                        $hr_chart_search->{where} = [{
-                            operator => '=',
-                            column   => 'VALUE_ID',
-                            values   => \@a_bench_value_ids,
-                        }];
+                        $hr_chart_search->{where} = [[
+                            '=',
+                            'VALUE_ID',
+                            @a_bench_value_ids,
+                        ]];
                     }
                     else {
                         last LOADING_DATA;
@@ -404,11 +408,11 @@ sub get_chart_points : Local {
                                 $_->chart_line_restriction_value
                             } $or_chart_line_restriction->chart_line_restriction_values;
                         }
-                        push @{$hr_chart_search->{where}}, {
-                            operator => $or_chart_line_restriction->chart_line_restriction_operator,
-                            column   => $or_chart_line_restriction->chart_line_restriction_column,
-                            values   => \@a_chart_line_restriction_value,
-                        };
+                        push @{$hr_chart_search->{where}}, [
+                            $or_chart_line_restriction->chart_line_restriction_operator,
+                            $or_chart_line_restriction->chart_line_restriction_column,
+                            @a_chart_line_restriction_value,
+                        ];
                     }
                 }
                 else {
@@ -428,7 +432,7 @@ sub get_chart_points : Local {
                     keys %h_chart_search_select
                 ];
 
-                my $ar_chart_points = $or_bench->search_array( $hr_chart_search );
+                my $ar_chart_points = $balib->search( $hr_chart_search );
 
                 if ( $ar_chart_points && @{$ar_chart_points} ) {
 
@@ -751,18 +755,14 @@ sub get_columns : Private {
 
     my ( $or_self, $or_c ) = @_;
 
-    my @a_columnlist = $or_c->model('TestrunDB')
-        ->resultset('BenchAdditionalTypes')
-        ->get_column('bench_additional_type')
-        ->all()
-    ;
+    require Tapper::Config;
+    require BenchmarkAnything::Storage::Frontend::Lib;
 
-    push @a_columnlist, keys %{Tapper::Benchmark
-        ->new({ dbh => Tapper::Model::model()->storage->dbh, })
-        ->{query}
-        ->default_columns()
-        }
-    ;
+    my $balib = BenchmarkAnything::Storage::Frontend::Lib->new
+      (cfgfile => Tapper::Config->subconfig->{_last_used_tapper_config_file});
+
+    my @a_columnlist = @{$balib->listkeys};
+    push @a_columnlist, keys %{$balib->_default_additional_keys}; # TODO: too much unrequested data from this?
 
     return \@a_columnlist;
 
@@ -772,20 +772,17 @@ sub is_column : Private {
 
     my ( $or_self, $or_c, $s_column ) = @_;
 
-    my $hr_columns = Tapper::Benchmark
-        ->new({ dbh => Tapper::Model::model()->storage->dbh, })
-        ->{query}
-        ->default_columns()
-    ;
+    require Tapper::Config;
+    require BenchmarkAnything::Storage::Frontend::Lib;
+
+    my $balib = BenchmarkAnything::Storage::Frontend::Lib->new
+      (cfgfile => Tapper::Config->subconfig->{_last_used_tapper_config_file});
+
+    my $hr_columns = $balib->_default_additional_keys;
 
     return 1 if $hr_columns->{$s_column};
 
-    my @a_columnlist = $or_c->model('TestrunDB')
-        ->resultset('BenchAdditionalTypes')
-        ->search({ bench_additional_type => $s_column })
-        ->get_column('bench_additional_type_id')
-        ->all()
-    ;
+    my @a_columnlist = $balib->_get_additional_key_id($s_column);
 
     return @a_columnlist ? 1 : 0;
 
@@ -1062,8 +1059,8 @@ sub save_chart : Local {
     my $hr_search_param = {
         'chart.active'  => 1,
         'chart_name'    => $hr_params->{chart_name},
-        'chart_version' => \'>= ALL(
-            SELECT cv.chart_version
+        'chart_version' => \'>= (
+            SELECT MAX(cv.chart_version)
             FROM chart_versions cv
             WHERE cv.chart_id = me.chart_id
         )',
@@ -1170,10 +1167,11 @@ sub insert_chart : Private {
     my $hr_params  = $or_c->stash->{chart};
     my $i_chart_id = $hr_params->{chart_id};
 
+    my $NOW = DateTime->now();
     if (! $i_chart_id ) {
         my $or_chart = $or_schema->resultset('Charts')->new({
             active      => 1,
-            created_at  => \'NOW()',
+            created_at  => $NOW,
         });
         $or_chart->insert();
         $i_chart_id = $or_chart->chart_id;
@@ -1194,7 +1192,7 @@ sub insert_chart : Private {
         chart_name              => $hr_params->{chart_name},
         order_by_x_axis         => $hr_params->{order_by_x_axis},
         order_by_y_axis         => $hr_params->{order_by_y_axis},
-        created_at              => \'NOW()',
+        created_at              => $NOW,
     });
     $or_chart_version->insert();
 
@@ -1208,6 +1206,7 @@ sub insert_chart : Private {
                 chart_line_name             => $hr_chart_line->{chart_line_name},
                 chart_axis_x_column_format  => $hr_chart_line->{chart_line_x_format} || undef,
                 chart_axis_y_column_format  => $hr_chart_line->{chart_line_y_format} || undef,
+                created_at                  => $NOW,
             });
             $or_chart_line->insert();
 
@@ -1246,6 +1245,7 @@ sub insert_chart : Private {
                         chart_line_id                => $i_chart_line_id,
                         chart_line_additional_column => $hr_additionals->{chart_line_additional_column},
                         chart_line_additional_url    => $hr_additionals->{chart_line_additional_url} || undef,
+                        created_at                   => $NOW,
                     })->insert();
                 }
 
@@ -1257,7 +1257,7 @@ sub insert_chart : Private {
                         chart_line_restriction_operator => $hr_chart_line_restriction->{chart_line_restriction_operator},
                         is_template_restriction         => $hr_chart_line_restriction->{is_template_restriction},
                         is_numeric_restriction          => $hr_chart_line_restriction->{is_numeric_restriction},
-                        created_at                      => \'NOW()',
+                        created_at                      => $NOW,
                     });
                     $or_chart_line_restriction->insert();
 
@@ -1330,6 +1330,7 @@ sub insert_chart_tags : Private {
         }
     }
 
+    my $NOW = DateTime->now();
     for my $s_chart_tag ( keys %h_chart_tags_new ) {
         $or_schema
             ->resultset('ChartTagRelations')
@@ -1338,11 +1339,11 @@ sub insert_chart_tags : Private {
                 chart_tag_id => $or_schema
                     ->resultset('ChartTags')
                     ->find_or_create(
-                        { chart_tag => $s_chart_tag, created_at => \'NOW()' },
+                        { chart_tag => $s_chart_tag, created_at => $NOW },
                         { key       => 'ux_chart_tags_01'                   },
                     )->chart_tag_id
                 ,
-                created_at   => \'NOW()',
+                created_at   => $NOW,
             })
         ;
     }
@@ -1363,8 +1364,9 @@ sub remove_chart : Private {
         $i_chart_id,
     );
 
+    my $NOW = DateTime->now();
     $or_chart->active(0);
-    $or_chart->updated_at(\'NOW()');
+    $or_chart->updated_at($NOW);
     $or_chart->update();
 
     return q##;
@@ -1383,8 +1385,9 @@ sub remove_chart_version : Private {
         $i_chart_version_id
     );
 
+    my $NOW = DateTime->now();
     $or_chart->active(0);
-    $or_chart->updated_at(\'NOW()');
+    $or_chart->updated_at($NOW);
     $or_chart->update();
 
     return q##;
@@ -1395,12 +1398,13 @@ sub get_benchmark_operators : Private {
 
     my ( $or_self, $or_c ) = @_;
 
-    require Tapper::Benchmark;
-    return Tapper::Benchmark
-        ->new({ dbh => Tapper::Model::model()->storage->dbh, })
-        ->{query}
-        ->benchmark_operators()
-    ;
+    require Tapper::Config;
+    require BenchmarkAnything::Storage::Frontend::Lib;
+
+    my $balib = BenchmarkAnything::Storage::Frontend::Lib->new
+      (cfgfile => Tapper::Config->subconfig->{_last_used_tapper_config_file});
+
+    return @{$balib->_get_benchmark_operators || []};
 
 }
 
