@@ -95,7 +95,7 @@ function get_chart_points ( $act_chart, params ) {
             dataType : 'json',
             url      : get_chart_point_url($act_chart),
             error    : function () {
-                $act_chart.html('<span class="chart_error">unknown error occured</span>');
+                $act_chart.html('<span class="chart_error">aborted</span>');
                 return 0;
             },
             success  : function ( chart_data ) {
@@ -118,6 +118,7 @@ function get_chart_points ( $act_chart, params ) {
                 }
 
                 var options = {
+                    legend      : { position    : "nw" },
                     points      : { show        : true },
                     xaxis       : { show        : true },
                     yaxis       : { show        : true },
@@ -478,7 +479,7 @@ $(document).ready(function(){
         }
     });
     $('#columnA_2columns img.imgedit').click(function(){
-        location.href = '/tapper/metareports/edit_chart?chart_tag='+$('#idx_chart_tag').val()+'&amp;chart_id='+$(this).closest('.chart_boxs').attr('chart');
+        location.href = '/tapper/metareports/edit_chart?chart_tag='+$('#idx_chart_tag').val()+'&amp;chart_id='+$(this).closest('.chart_boxs').attr('chart')+'&amp;chart_version='+$('#idx_chart_version').val();
     });
     $('#columnA_2columns img.imgeditasnew').click(function(){
         location.href = '/tapper/metareports/edit_chart?chart_tag='+$('#idx_chart_tag').val()+'&amp;asnew=1&amp;chart_id='+$(this).closest('.chart_boxs').attr('chart');
@@ -486,4 +487,4 @@ $(document).ready(function(){
     $('#columnA_2columns img.imgjson').click(function(){
         location.href = get_chart_point_url($(this).closest('div.chart_boxs').find('div.charts'));
     });
-});
\ No newline at end of file
+});
